@@ -1,9 +1,9 @@
 import re
 import numpy as np
 
-def generate_VDW_dict_from_universe(ucg):
+def generate_VDW_dict_from_universe(ucg, selector):
     vdw_d = {}
-    sel = ucg.select_atoms('all')
+    sel = ucg.select_atoms(selector)
 
     for res in np.unique(sel.resnames):
         R = sel.select_atoms('resname {}'.format(res))
